@@ -1,26 +1,26 @@
-#' Illustrate a Chi-Squared Test graphically.
+#' Illustrate a \eqn{\chi^2}{\chi-squared} test graphically.
 #'
-#' This function plots the density probability distribution of a Chi-Squared statistic, with a vertical cutline at the observed Chi-Squared value specified. The p-value and the observed Chi-Squared value are plotted. Although largely customizable, only two arguments are required (the observed Chi-Squared and the degrees of freedom).
+#' This function plots the density probability distribution of a \eqn{\chi^2}{\chi-squared} statistic, with a vertical cutline at the observed \eqn{\chi^2}{\chi-squared} value specified. The p-value and the observed \eqn{\chi^2}{\chi-squared} value are plotted. Although largely customizable, only two arguments are required (the observed \eqn{\chi^2}{\chi-squared} and the degrees of freedom).
 #'
-#' @param chisq A numeric value indicating the observed Chi-squared statistic.
-#' @param df A numeric value indicating the degrees of freedom.
-#' @param blank A logical that indicates whether to hide (blank = TRUE) the test statistic value, p value and cutline. The corresponding colors are actually only made transparent when blank = TRUE, so that the output is scaled exactly the same (this is useful and especially intended for step-by-step explanations).
-#' @param title A string or expression indicating a custom title for the plot (optional).
-#' @param xlabel A string or expression indicating a custom title for the x axis (optional).
-#' @param ylabel A string or expression indicating a custom title for the y axis (optional).
-#' @param fontfamily A string indicating the font family of all the titles and labels (e.g. "serif" (default), "sans", "Helvetica", "Palatino", etc.) (optional).
-#' @param colorleft A string indicating the color for the "left" area under the curve (optional).
-#' @param colorright A string indicating the color for the "right" area under the curve (optional).
-#' @param colorleftcurve A string indicating the color for the "left" part of the curve (optional).
-#' @param colorrightcurve A string indicating the color for the "right" part of the curve (optional). By default, for color consistency, this color is also passed to the label, but this can be changed by providing an argument for the "colorlabel" parameter.
-#' @param colorcut A string indicating the color for the cut line at the observed test statistic (optional).
-#' @param colorplabel A string indicating the color for the label of the p-value (optional). By default, for color consistency, this color is the same as color of "colorright".
-#' @param theme A string indicating one of the predefined color themes. The themes are "default" (light blue and red), "blackandwhite", "whiteandred", "blueandred", "greenandred" and "goldandblue") (optional). Supersedes "colorleft" and "colorright" if another argument than "default" is provided.
-#' @param signifdigitsp A numeric indicating the number of desired significant figures reported for the p-value label (optional).
-#' @param signifdigitschisq A numeric indicating the number of desired significant figures reported for the Chi-Squared label (optional).
+#' @param chisq A numeric value indicating the observed \eqn{\chi^2}{\chi-squared} statistic. Alternatively, you can use an object of class \code{htest} created by the function \code{chisq.test()}.
+#' @param df A numeric value indicating the degrees of freedom. This argument is optional if you are using an \code{htest} object as the \code{chisq} argument.
+#' @param blank A logical that indicates whether to hide (\code{blank = TRUE}) the test statistic value, p value and cutline. The corresponding colors are actually only made transparent when \code{blank = TRUE}, so that the output is scaled exactly the same (this is useful and especially intended for step-by-step explanations).
+#' @param xmax A numeric including the maximum for the x-axis. Defaults to \code{"auto"}, which scales the plot automatically (optional).
+#' @param title A character or expression indicating a custom title for the plot (optional).
+#' @param xlabel A character or expression indicating a custom title for the x axis (optional).
+#' @param ylabel A character or expression indicating a custom title for the y axis (optional).
+#' @param fontfamily A character indicating the font family of all the titles and labels (e.g. \code{"serif"} (default), \code{"sans"}, \code{"Helvetica"}, \code{"Palatino"}, etc.) (optional).
+#' @param colorleft A character indicating the color for the "left" area under the curve (optional).
+#' @param colorright A character indicating the color for the "right" area under the curve (optional).
+#' @param colorleftcurve A character indicating the color for the "left" part of the curve (optional).
+#' @param colorrightcurve A character indicating the color for the "right" part of the curve (optional). By default, for color consistency, this color is also passed to the label, but this can be changed by providing an argument for the \code{colorlabel} parameter.
+#' @param colorcut A character indicating the color for the cut line at the observed test statistic (optional).
+#' @param colorplabel A character indicating the color for the label of the p-value (optional). By default, for color consistency, this color is the same as color of \code{colorright}.
+#' @param theme A character indicating one of the predefined color themes. The themes are \code{"default"} (light blue and red), \code{"blackandwhite"}, \code{"whiteandred"}, \code{"blueandred"}, \code{"greenandred"} and \code{"goldandblue"}) (optional). Supersedes \code{colorleft} and \code{colorright} if another argument than \code{"default"} is provided.
+#' @param signifdigitschisq A numeric indicating the number of desired significant figures reported for the \eqn{\chi^2}{\chi-squared} label (optional).
 #' @param curvelinesize A numeric indicating the size of the curve line (optional).
 #' @param cutlinesize A numeric indicating the size of the cut line (optional). By default, the size of the curve line is used.
-#' @return Returns a plot with the density of probability of Chi-Squared under the null hypothesis, annotated with the observed test statistic and the p-value.
+#' @return A plot with the density of probability of \eqn{\chi^2}{\chi-squared} under the null hypothesis, annotated with the observed test statistic and the p-value.
 #' @export plotchisqtest
 #' @examples
 #' #Making a chi-squared plot with Chi-squared of 8 and df of 4
@@ -32,37 +32,52 @@
 #' #The same plot without the Chi-Squared or p value
 #' plotchisqtest(8,4, blank = TRUE)
 #'
-#' #Changing the fontfamily to "sans" and changing the color theme to "blackandwhite"
-#' plotchisqtest(chisq = 8, df = 4, fontfamily = "sans", theme = "blackandwhite")
-#'
-#' #Using specific colors and changing the curve line size
-#' plotchisqtest(chisq = 8, df = 4, colorleft = "grey", colorright = "indianred", curvelinesize = 1.2)
-#'
-#' #Changing the title to "Chi-Squared Test of Independence"
-#' plotchisqtest(chisq = 8, df = 4, title = "Chi-Squared Test of Independence")
-#'
-#' #Changing the title to "Chi-Squared Test of Independence" with greek chi-squared
-#' plotchisqtest(chisq = 8, df = 4, title = expression(chi^2 ~ "Test" ~ "of" ~ "Independence"))
+#' #Plot using a chisq.test()
+#' test <- chisq.test(c(A = 37, B = 18, C = 25))
+#' plotchisqtest(test)
 #'
 #' @author Nils Myszkowski <nmyszkowski@pace.edu>
-plotchisqtest <- function(chisq, df, blank = FALSE, title = parse(text = expression(chi^2 ~ "Test")), xlabel = parse(text = expression(chi^2)), ylabel = "Density of probability\nunder the null hypothesis", fontfamily = "serif", colorleft = "aliceblue", colorright = "firebrick3", colorleftcurve = "black", colorrightcurve = "black", colorcut = "black", colorplabel = colorright, theme = "default", signifdigitsp = 3, signifdigitschisq = 3, curvelinesize = .4, cutlinesize = curvelinesize) {
+plotchisqtest <- function(chisq, df = chisq$parameter, blank = FALSE, xmax = "auto", title = parse(text = expression(chi^2 ~ "Test")), xlabel = parse(text = expression(chi^2)), ylabel = "Density of probability\nunder the null hypothesis", fontfamily = "serif", colorleft = "aliceblue", colorright = "firebrick3", colorleftcurve = "black", colorrightcurve = "black", colorcut = "black", colorplabel = colorright, theme = "default", signifdigitschisq = 3, curvelinesize = .4, cutlinesize = curvelinesize) {
   x=NULL
+
+
+  # If t is a t.test() object, then mine it to get t and df
+  if (class(chisq) == "htest") {
+    df <- chisq$parameter
+    chisq <- chisq$statistic
+  }
+
+  #Unname inputs (can cause issues)
+  chisq <- unname(chisq)
+  df <- unname(df)
+
+
   #Create a function to restrict plotting areas to specific bounds of x
-    area_range <- function(fun, min, max) {
-      function(x) {
-        y <- fun(x)
-        y[x < min | x > max] <- NA
-        return(y)
-      }
+  area_range <- function(fun, min, max) {
+    function(x) {
+      y <- fun(x)
+      y[x < min | x > max] <- NA
+      return(y)
     }
+  }
+
+  # Function to format p value
+  p_value_format <- function(p) {
+    if (p < .001) {"< .001"} else
+      if (p > .999) {"> .999"} else
+        paste0("= ", substr(sprintf("%.3f", p), 2, 5))
+  }
+
   #Calculate the p value
   pvalue <- stats::pchisq(chisq, df, lower.tail = FALSE)
   #Label for p value
-  plab <- paste("p =", signif(pvalue, digits = signifdigitsp), sep = " ")
+  plab <- paste0("p ", p_value_format(pvalue))
   #Label for chi square value
-  chisqlab <- as.character(as.expression(bquote(chi^2== .(signif(chisq, digits=signifdigitschisq)))))
+  chisqlab <- as.character(as.expression(bquote(chi^2==.(signif(chisq, digits=signifdigitschisq)))))
   #Define x axis bounds as the maximum between 1.5*f or 3 (this avoids only the tip of the curve to be plotted when F is small, and keeps a nice t curve shape display)
-  xbound <- max(1.5*chisq, 5)
+  if (xmax == "auto") {
+    xbound <- max(1.5*chisq, 5)
+  } else {xbound <- xmax}
   #To ensure lines plotted by stat_function are smooth
   precisionfactor <-  5000
   #To define the function to plot in stat_function
@@ -100,6 +115,10 @@ plotchisqtest <- function(chisq, df, blank = FALSE, title = parse(text = express
     colorleft <- "#FFC61E"
     colorright <- "#00337F"
     colorplabel <- "#00337F"
+  } else if (theme == "mysql") {
+    colorleft <- "#00758f"
+    colorright <- "#f29111"
+    colorplabel <- "#f29111"
   } else warning("The ",'"', "theme", '"', " argument was not recognized. See documentation for a list of available color themes. Reverting to default.")
   #To make some colors transparent when `blank` parameter is TRUE (to only plot de probability density function in that case)
   if (blank == TRUE) {
